@@ -2,15 +2,17 @@ from typing import Any, Callable, Dict, List, Optional
 
 import attr
 
+from ..models.endpoint_addresses import EndpointAddresses
 from ..types import UNSET
 from ..util.serialization import is_not_none
 
 
 @attr.s(auto_attribs=True)
 class Endpoint:
-    """ An Endpoint is the entry point for remote access to a QuantumProcessor. """
+    """An Endpoint is the entry point for remote access to a QuantumProcessor."""
 
     address: str
+    addresses: EndpointAddresses
     healthy: bool
     id: str
     mock: bool
@@ -19,6 +21,8 @@ class Endpoint:
 
     def to_dict(self, pick_by_predicate: Optional[Callable[[Any], bool]] = is_not_none) -> Dict[str, Any]:
         address = self.address
+        addresses = self.addresses.to_dict()
+
         healthy = self.healthy
         id = self.id
         mock = self.mock
@@ -29,6 +33,7 @@ class Endpoint:
         field_dict.update(
             {
                 "address": address,
+                "addresses": addresses,
                 "healthy": healthy,
                 "id": id,
                 "mock": mock,
@@ -47,6 +52,8 @@ class Endpoint:
         d = src_dict.copy()
         address = d.pop("address")
 
+        addresses = EndpointAddresses.from_dict(d.pop("addresses"))
+
         healthy = d.pop("healthy")
 
         id = d.pop("id")
@@ -57,6 +64,7 @@ class Endpoint:
 
         endpoint = Endpoint(
             address=address,
+            addresses=addresses,
             healthy=healthy,
             id=id,
             mock=mock,
